/*
 * Copyright (C) 2012 Erich Douglass
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.github.erd.presenter.example;

import android.os.Bundle;
import android.view.View;
import android.content.Context;
import android.widget.TextView;
import android.app.ListActivity;

import com.github.erd.presenter.R;
import com.github.erd.presenter.ModelPresenter;
import com.github.erd.presenter.ModelPresenterAdapter;

/**
 * Example of using a Presenter in a list view.
 */
public class PresenterExample extends ListActivity {

    @Override
    protected void onCreate(Bundle icicle) {
        super.onCreate(icicle);

        PersonAdapter adapter = new PersonAdapter(this);
        setListAdapter(adapter);

        for (int i = 0; i < 50; i++) {
            adapter.add(new Person(i, "Item #" + i));
        }
        adapter.notifyDataSetInvalidated();
    }

    private static class Person {

        private final long      id;

        private final String    name;

        private Person(long id, String name) {
            this.id = id;
            this.name = name;
        }
    }

    private static class PersonPresenter extends ModelPresenter<Person> {

        private final TextView      id;

        private final TextView      name;

        private PersonPresenter(View view) {
            this.id   = (TextView) view.findViewById(R.id.id);
            this.name = (TextView) view.findViewById(R.id.name);
        }

        @Override
        public void setViewValues(Context context, Person model) {
            this.id.setText(String.valueOf(model.id));
            this.name.setText(model.name);
        }
    }

    private static class PersonAdapter extends ModelPresenterAdapter<Person> {

        private PersonAdapter(Context context) {
            super(context, R.layout.list_item_text2);
        }

        @Override
        protected PersonPresenter getViewPresenter(View view) {
            return new PersonPresenter(view);
        }
    }
}
